==> oarepo_oai_pmh_harvester-4.0.37-py3-none-any.whl: oarepo_oaipmh_harvester/oai_record/services/records/schema.py <==
import marshmallow as ma
from marshmallow import Schema
from marshmallow import fields as ma_fields
from marshmallow.fields import String
from marshmallow.validate import OneOf
from oarepo_runtime.services.schema.marshmallow import BaseRecordSchema
from oarepo_runtime.services.schema.validation import validate_datetime


class OaiRecordSchema(BaseRecordSchema):
    class Meta:
        unknown = ma.RAISE

    batch = ma_fields.Nested(lambda: BatchSchema(), required=True)

    context = ma_fields.Dict()

    datestamp = ma_fields.String(validate=[validate_datetime])

    entry = ma_fields.Dict()

    errors = ma_fields.List(ma_fields.Nested(lambda: ErrorsItemSchema()))

    harvester = ma_fields.Nested(lambda: HarvesterSchema(), required=True)

    local_identifier = ma_fields.String()

    manual = ma_fields.Boolean()

    oai_identifier = ma_fields.String()

    run = ma_fields.Nested(lambda: BatchSchema(), required=True)

    status = ma_fields.String(validate=[OneOf(["O", "W", "E", "S"])])

    title = ma_fields.String()

    warnings = ma_fields.List(ma_fields.String())


class BatchSchema(Schema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma_fields.String(data_key="id", attribute="id")

    _version = String(data_key="@v", attribute="@v")


class ErrorsItemSchema(Schema):
    class Meta:
        unknown = ma.RAISE

    code = ma_fields.String()

    info = ma_fields.Dict()

    location = ma_fields.String()

    message = ma_fields.String()


class HarvesterSchema(Schema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma_fields.String(data_key="id", attribute="id")

    _version = String(data_key="@v", attribute="@v")

    writer = ma_fields.String()

==> oarepo_oai_pmh_harvester-4.0.40-py3-none-any.whl: oarepo_oaipmh_harvester/oai_record/services/records/schema.py <==
import marshmallow as ma
from marshmallow import Schema
from marshmallow import fields as ma_fields
from marshmallow.fields import String
from oarepo_runtime.services.schema.marshmallow import BaseRecordSchema
from oarepo_runtime.services.schema.validation import validate_datetime


class OaiRecordSchema(BaseRecordSchema):
    class Meta:
        unknown = ma.RAISE

    batch = ma_fields.Nested(lambda: BatchSchema(), required=True)

    context = ma_fields.Dict()

    datestamp = ma_fields.String(validate=[validate_datetime])

    entry = ma_fields.Dict()

    errors = ma_fields.List(ma_fields.Nested(lambda: ErrorsItemSchema()))

    harvester = ma_fields.Nested(lambda: HarvesterSchema(), required=True)

    local_identifier = ma_fields.String()

    manual = ma_fields.Boolean()

    oai_identifier = ma_fields.String()

    run = ma_fields.Nested(lambda: RunSchema(), required=True)

    title = ma_fields.String()


class BatchSchema(Schema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma_fields.String(data_key="id", attribute="id")

    _version = String(data_key="@v", attribute="@v")

    sequence = ma_fields.Integer()

    started = ma_fields.String(validate=[validate_datetime])


class ErrorsItemSchema(Schema):
    class Meta:
        unknown = ma.RAISE

    code = ma_fields.String()

    info = ma_fields.Dict()

    location = ma_fields.String()

    message = ma_fields.String()


class HarvesterSchema(Schema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma_fields.String(data_key="id", attribute="id")

    _version = String(data_key="@v", attribute="@v")

    code = ma_fields.String()

    name = ma_fields.String()


class RunSchema(Schema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma_fields.String(data_key="id", attribute="id")

    _version = String(data_key="@v", attribute="@v")

    started = ma_fields.String(validate=[validate_datetime])

    title = ma_fields.String()
